@@ -25,7 +25,10 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <string.h>
+
+#include <glib/gi18n.h>
+
 #include "gst.h"
 
 #include "disks-storage.h"
@@ -354,7 +357,7 @@ gst_on_format_button_clicked (GtkWidget *button, gpointer gdata)
 															 point);
 								gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
 																  _("Access Path \"%s\" is already being "
-																    "used by other partition"), point);
+																    "used by other partition."), point);
 								gtk_dialog_run (GTK_DIALOG (msgdialog));
 								gtk_widget_destroy (msgdialog);
 								
